package cn.net.caoyao.cpzshandset.service.thread.impl.common;

import java.io.IOException;
import java.net.BindException;
import java.net.ConnectException;
import java.net.SocketTimeoutException;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;

import android.os.Handler;
import android.os.Message;
import cn.net.caoyao.cpzshandset.bean.SaleBean;
import cn.net.caoyao.cpzshandset.bean.SingleLabelOptionBean;
import cn.net.caoyao.cpzshandset.bean.UploadBean;
import cn.net.caoyao.cpzshandset.common.config.Config;
import cn.net.caoyao.cpzshandset.common.config.HandsetOperation;
import cn.net.caoyao.cpzshandset.common.config.InternalOptionConstant;
import cn.net.caoyao.cpzshandset.common.config.RequestConstant;
import cn.net.caoyao.cpzshandset.common.config.TConfig;
import cn.net.caoyao.cpzshandset.common.util.LogUtil;
import cn.net.caoyao.cpzshandset.service.bll.SalesBll;
import cn.net.caoyao.cpzshandset.service.bll.SingleLabelBll;
import cn.net.caoyao.cpzshandset.service.bll.UploadStatusBll;
import cn.net.cpzslibs.prot.Prot02Logout;
import cn.net.cpzslibs.prot.SocketCreate;
import cn.net.cpzslibs.prot.bean.res.ProtStatusResBean;
import cn.net.cpzslibs.prot.handset.bean.req.Prot20005ReqBean;
import cn.net.cpzslibs.prot.handset.bean.req.Prot20017ReqBean;
import cn.net.cpzslibs.prot.handset.bean.res.Prot20017LabelBean;
import cn.net.cpzslibs.prot.handset.newProt.Prot20005LabelOption;
import cn.net.cpzslibs.prot.handset.newProt.Prot20017CheckLabelStatus;

public class CommonSubmitSalesThread implements Runnable {
	private long deviceId;
	private SalesBll bll;
	private SingleLabelBll labelBll;
	private UploadStatusBll uploadStatusBll;
	private Handler mHandler;
	private int option_type = HandsetOperation.OPERATION_SALE_CONSTANT.getOption();
	private List<SaleBean> saleBeans;

	public CommonSubmitSalesThread(Handler mHandler,long deviceId,SalesBll bll,SingleLabelBll labelBll,UploadStatusBll uploadStatusBll,List<SaleBean> saleBeans) {
		this.mHandler = mHandler;
		this.deviceId = deviceId;
		this.bll = bll;
		this.labelBll = labelBll;
		this.uploadStatusBll = uploadStatusBll;
		this.saleBeans = saleBeans;
	}

	@Override
	public void run() {
		SocketCreate create = new SocketCreate(Config.ip, Config.port, "");
		try {
			LogUtil.d(TConfig.Echo, "登录");
			create.createLoginCpzsHandset(deviceId);
			if (create.isResult()) {
				submitSalesInfo(create);
			} else {
				Message msg = new Message();
				msg.what = RequestConstant.REQUEST_PROT01_LOGIN_FAIL;
				msg.arg1 = create.getiErrCode();
				msg.obj = create.getErrMsg();
				mHandler.sendMessage(msg);
			}
			
		} catch (BindException e) {
			e.printStackTrace();
			mHandler.sendEmptyMessage(RequestConstant.REQUEST_FAIL);
		} catch (ConnectException e) {
			e.printStackTrace();
			mHandler.sendEmptyMessage(RequestConstant.REQUEST_FAIL);
		} catch (SocketTimeoutException e) {
			e.printStackTrace();
			mHandler.sendEmptyMessage(RequestConstant.REQUEST_FAIL_SOCKET_TIMEOUT);
		} catch (UnknownHostException e) {
			e.printStackTrace();
			mHandler.sendEmptyMessage(RequestConstant.REQUEST_FAIL);
		} catch (IOException e) {
			e.printStackTrace();
			mHandler.sendEmptyMessage(RequestConstant.REQUEST_FAIL);
		}finally {
			new Prot02Logout().dealLogout(create);
		}
	}


	private void submitSalesInfo(SocketCreate create) throws IOException{
		for (SaleBean b : saleBeans) {
			int count = labelBll.queryLabelCountById(option_type, b.getId());
			if (count > 0) {
				Prot20005LabelOption labelOption = new Prot20005LabelOption();
				labelOption.submitLabelOptionInfo(create, getProt20005ReqBean(b));
				
				
				ProtStatusResBean resBean = labelOption.getResBean();
				if (resBean != null ) {
					if (resBean.getResult() == 0) {
						//成功
						uploadStatusBll.insertUploadStatus(getUploadBean(b));
						bll.deleteSalesById(b);
					} else {
						//失败
						bll.updateSalesSubmitStatus(Config.SUBMIT_STATUS_SUBMIT_FAIL, resBean.getErrcode(), b.getId());
						checkLabel(create, b);
					}
				}
				
			}
		}
		
		mHandler.sendEmptyMessage(RequestConstant.SUBMIT_ALL_SALES_COMPLETE);
	}
	private void checkLabel(SocketCreate create,SaleBean b) throws IOException{
		Prot20017CheckLabelStatus prot20017 = new Prot20017CheckLabelStatus();
		prot20017.checkLabel(create, getProt20017ReqBean(b));
		if (prot20017.getResBean() != null && prot20017.getResBean().getResult() == 0) {
			List<Prot20017LabelBean> invilad = prot20017.getResBean().getLabel_invalid();
			if (invilad != null) {
				List<String> inviladLabel = new ArrayList<>();
				for (Prot20017LabelBean prot20017LabelBean : invilad) {
					inviladLabel.add(prot20017LabelBean.getLabel_id());
				}
				labelBll.updateLableStatusById(inviladLabel, option_type, b.getId(), InternalOptionConstant.SINGLE_LABEL_STATUS_INVALID);
			}
			
			List<Prot20017LabelBean> noActivate = prot20017.getResBean().getLabel_not_active();
			if (noActivate != null) {
				List<String> noActivateLabel = new ArrayList<>();
				for (Prot20017LabelBean prot20017LabelBean : noActivate) {
					noActivateLabel.add(prot20017LabelBean.getLabel_id());
				}
				labelBll.updateLableStatusById(noActivateLabel, option_type, b.getId(), InternalOptionConstant.SINGLE_LABEL_STATUS_NO_ACTIVATE);
			}
		}
		
	}

	private Prot20017ReqBean getProt20017ReqBean(SaleBean b) {
		Prot20017ReqBean reqBean = new Prot20017ReqBean();
		reqBean.setLabels(getLabels(b));
		reqBean.setOpt(3);
		return reqBean;
	}

	private Prot20005ReqBean getProt20005ReqBean(SaleBean saleB) {
		Prot20005ReqBean p = new Prot20005ReqBean();
		p.setLabels(getLabels(saleB));
		p.setOpt_description(saleB.getDescribe());
		p.setOpt(3);//1-出库 2-入库 3-销售 4-返库 5-采集 6-运输 7-贮藏
		p.setSales_area(saleB.getSales_area());
		return p;
	}


	private UploadBean getUploadBean(SaleBean sBean) {
		UploadBean b = new UploadBean();
		b.setLabel_count(labelBll.queryLabelCountById(option_type, sBean.getId()));
		b.setOption_type(option_type);
		return b;
	}


	private List<String> getLabels(SaleBean saleB) {
		List<String> singles = new ArrayList<>();
		List<SingleLabelOptionBean> singleOptions = labelBll.queryAllLabelById(option_type, saleB.getId());
		for (SingleLabelOptionBean sLBean : singleOptions) {
			singles.add(sLBean.getLabel_id());
		}
		return singles;
	}


}
